/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: cryptmanager_l.h 791 2005-07-23 09:39:42Z aquamaniac $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef GCT_TOOL_CRYPTMANAGER_L_H
#define GCT_TOOL_CRYPTMANAGER_L_H

#include <gwenhywfar/misc.h>
#include <gwenhywfar/misc2.h>
#include <gwenhywfar/inherit.h>
#include <gwenhywfar/crypttoken.h>


GWEN_PLUGIN_MANAGER *CON_CryptManager_new();




#endif /* GCT_TOOL_CRYPTMANAGER_L_H */
